@@ -1,8 +1,9 @@
 from pathlib import Path
 
-from pydantic import BaseModel, Field
+from pydantic import AliasChoices, BaseModel, Field
 
 from unique_toolkit._common.default_language_model import DEFAULT_GPT_4o
+from unique_toolkit._common.pydantic_helpers import get_configuration_dict
 from unique_toolkit._common.validators import LMI, get_LMI_default_field
 from unique_toolkit.chat.schemas import (
     ChatMessageAssessmentType,
@@ -22,12 +23,13 @@ with open(Path(__file__).parent / "summarization_user_message.j2", "r") as file:
     DEFAULT_SUMMARIZATION_USER_MESSAGE_TEMPLATE = file.read().strip()
 
 
-class SubAgentEvaluationConfig(BaseModel):
+class SubAgentEvaluationServiceConfig(BaseModel):
+    model_config = get_configuration_dict()
+
     assessment_type: ChatMessageAssessmentType = Field(
         default=ChatMessageAssessmentType.COMPLIANCE,
         description="The type of assessment to use in the display.",
     )
-
     summarization_model: LMI = get_LMI_default_field(DEFAULT_GPT_4o)
     summarization_system_message: str = Field(
         default=DEFAULT_EVALUATION_SYSTEM_MESSAGE_TEMPLATE,
@@ -37,3 +39,17 @@ class SubAgentEvaluationConfig(BaseModel):
         default=DEFAULT_SUMMARIZATION_USER_MESSAGE_TEMPLATE,
         description="The user message template for the summarization model.",
     )
+
+
+class SubAgentEvaluationConfig(BaseModel):
+    model_config = get_configuration_dict()
+
+    include_evaluation: bool = Field(
+        default=True,
+        description="Whether to include the evaluation in the response.",
+        validation_alias=AliasChoices(
+            "includeEvaluation",
+            "displayEvalution",  # typo in old config name
+            "display_evalution",
+        ),
+    )
